@@ -3,7 +3,7 @@
 #' Leave-one-out (LOO) cross-validation uses one data point in the original set as the assessment data and all other data points as the analysis set. A LOO resampling set has ass many resamples as rows in the original data set. 
 #'
 #' @inheritParams vfold_cv
-#' @return  An tibble with classes \code{loo_cv}, \code{rset}, \code{tbl_df}, \code{tbl}, and \code{data.frame}. The results include a column for the data split objects and one column called \code{id} that has a character string with the resample identifier.
+#' @return  An tibble with classes `loo_cv`, `rset`, `tbl_df`, `tbl`, and `data.frame`. The results include a column for the data split objects and one column called `id` that has a character string with the resample identifier.
 #' @examples
 #' loo_cv(mtcars)
 #' @importFrom purrr map
@@ -26,7 +26,7 @@ loo_cv <- function(data, ...) {
 
 #' @export
 print.loo_cv <- function(x, ...) {
-  cat("# Leave-one-out cross-validation\n")
+  cat("#", pretty(x), "\n")
   class(x) <- class(x)[!(class(x) %in% c("loo_cv", "rset"))]
   print(x)
 }
