@@ -3,14 +3,14 @@
 #' One resample of Monte Carlo cross-validation takes a random sample (without replacement) of the original data set to be used for analysis. All other data points are added to the assessment set. 
 #'
 #' @details 
-#' The \code{strata} argument causes the random sampling to be conducted \emph{within the stratification variable}. The can help ensure that the number of data points in the analysis data is equivalent to the proportions in the original data set.  
+#' The `strata` argument causes the random sampling to be conducted *within the stratification variable*. The can help ensure that the number of data points in the analysis data is equivalent to the proportions in the original data set.  
 #'
 #' @inheritParams vfold_cv
 #' @param prop The proportion of data to be retained for modeling/analysis. 
 #' @param times The number of times to repeat the sampling.. 
 #' @param strata A variable that is used to conduct stratified sampling to create the resamples. 
 #' @export
-#' @return  An tibble with classes \code{mc_cv}, \code{rset}, \code{tbl_df}, \code{tbl}, and \code{data.frame}. The results include a column for the data split objects and a column called \code{id} that has a character string with the resample identifier.
+#' @return  An tibble with classes `mc_cv`, `rset`, `tbl_df`, `tbl`, and `data.frame`. The results include a column for the data split objects and a column called `id` that has a character string with the resample identifier.
 #' @examples
 #' mc_cv(mtcars, times = 2)
 #' mc_cv(mtcars, prop = .5, times = 2)
@@ -100,20 +100,7 @@ strat_sample <- function(x, prop, times, ...) {
 
 #' @export
 print.mc_cv <- function(x, ...) {
-  details <- attributes(x)
-  cat(
-    "# Monte Carlo cross-validation (",
-    signif(details$prop, 2),
-    "/",
-    signif(1 - details$prop, 2),
-    ") with ",
-    details$times,
-    " resamples ",
-    sep = ""
-  )
-  if (details$strata) 
-    cat("using stratification")
-  cat("\n")
+  cat("#", pretty(x), "\n")
   class(x) <- class(x)[!(class(x) %in% c("mc_cv", "rset"))]
   print(x)
-}
\ No newline at end of file
+}
