@@ -3,9 +3,9 @@
 #' V-fold cross-validation randomly splits the data into V groups of roughly equal size (called "folds"). A resample of the analysis data consisted of V-1 of the folds while the assessment set contains the final fold. In basic V-fold cross-validation (i.e. no repeats), the number of resamples is equal to V. 
 
 #' @details 
-#' The \code{strata} argument causes the random sampling to be conducted \emph{within the stratification variable}. The can help ensure that the number of data points in the analysis data is equivalent to the proportions in the original data set.  
+#' The `strata` argument causes the random sampling to be conducted *within the stratification variable*. The can help ensure that the number of data points in the analysis data is equivalent to the proportions in the original data set.  
 #'
-#' When more than one repeat is requested, the basic V-fold cross-validation is conducted each time. For example, if three repeats are used with \code{v = 10}, there are a total of 30 splits which as three groups of 10 that are generated separately. 
+#' When more than one repeat is requested, the basic V-fold cross-validation is conducted each time. For example, if three repeats are used with `v = 10`, there are a total of 30 splits which as three groups of 10 that are generated separately. 
 #'
 #' @param data A data frame.
 #' @param v The number of partitions of the data set. 
@@ -13,7 +13,7 @@
 #' @param strata A variable that is used to conduct stratified sampling to create the folds. This should be a single character value. 
 #' @param ... Not currently used. 
 #' @export
-#' @return  An tibble with classes \code{vfold_cv}, \code{rset}, \code{tbl_df}, \code{tbl}, and \code{data.frame}. The results include a column for the data split objects and one or more identification variables. For a single repeats, there will be one column called \code{id} that has a character string with the fold identifier. For repeats, \code{id} is the repeat number and an additional column called \code{id2} that contains the fold information (within repeat). 
+#' @return  An tibble with classes `vfold_cv`, `rset`, `tbl_df`, `tbl`, and `data.frame`. The results include a column for the data split objects and one or more identification variables. For a single repeats, there will be one column called `id` that has a character string with the fold identifier. For repeats, `id` is the repeat number and an additional column called `id2` that contains the fold information (within repeat). 
 #' @examples
 #' vfold_cv(mtcars, v = 10)
 #' vfold_cv(mtcars, v = 10, repeats = 2)
@@ -111,13 +111,7 @@ add_vfolds <- function(x, v) {
 
 #' @export
 print.vfold_cv <- function(x, ...) {
-  details <- attributes(x)
-  cat("# ", details$v, "-fold cross-validation ", sep = "")
-  if (details$repeats > 1)
-    cat("repeated", details$repeats, "times ")
-  if (details$strata)
-    cat("using stratification")
-  cat("\n")
+  cat("# ", pretty(x), "\n")
   class(x) <- class(x)[!(class(x) %in% c("vfold_cv", "rset"))]
   print(x)
-}
\ No newline at end of file
+}
